@@ -9,6 +9,13 @@ import webbrowser as _webbrowser
 import asyncio
 from autobahn.asyncio.websocket import WebSocketServerProtocol, WebSocketServerFactory
 
+import signal 
+
+# Check for Ctrl+C 
+def signal_handler(signal, frame):
+    os._exit(0)
+signal.signal(signal.SIGINT, signal_handler)
+
 # Requests from client to http server can be the following:
 #    get glowcomm.html, library .js files, images, or font files
 
@@ -151,6 +158,7 @@ class WSserver(WebSocketServerProtocol):
     def onClose(self, wasClean, code, reason):
         #print("Server WebSocket connection closed: {0}".format(reason))
         self.connection = None
+        os._exit(0)
 
 try:
     if platform.python_implementation() == 'PyPy':
